Enums
Functions
- Create an error from multiple errors
- Create an error from multiple errors, attaching attributes
- Create a new error. If you want to inherit attributes from a logging context, see
Log::err. - Create a new error and attach attributes. If you want to inherit attributes from a logging context, see
Log::err. - Log a fatal error and terminate the program.
Type Aliases
- A logger using a preconfigured flag set.